@@ -2,6 +2,7 @@ package Minion::Job;
 use Mojo::Base 'Mojo::EventEmitter';
 
 use Carp qw(croak);
+use Mojo::Collection;
 use Mojo::IOLoop;
 use POSIX qw(WNOHANG);
 
@@ -30,7 +31,7 @@ sub finish {
   return $ok ? !!$self->emit(finished => $result) : undef;
 }
 
-sub info { $_[0]->minion->backend->list_jobs(0, 1, {ids => [$_[0]->id]})->{jobs}[0]; }
+sub info { $_[0]->minion->backend->list_jobs(0, 1, {ids => [$_[0]->id]})->{jobs}[0] }
 
 sub is_finished {
   my $self = shift;
@@ -46,6 +47,12 @@ sub note {
   return $self->minion->backend->note($self->id, {@_});
 }
 
+sub parents {
+  my $self   = shift;
+  my $minion = $self->minion;
+  return Mojo::Collection->new(map { $minion->job($_) // () } @{($self->info || {})->{parents} || []});
+}
+
 sub perform {
   my $self = shift;
   waitpid $self->start->pid, 0;
@@ -362,6 +369,12 @@ Epoch time job is valid until before it expires.
 
 Epoch time job was finished.
 
+=item lax
+
+  lax => 0
+
+Existing jobs this job depends on may also have failed to allow for it to be processed.
+
 =item notes
 
   notes => {foo => 'bar', baz => [1, 2, 3]}
@@ -463,6 +476,18 @@ binary data, nested data structures with hash and array references are fine thou
   # Share stats
   $job->note(stats => {utime => '0.012628', stime => '0.002429'});
 
+=head2 parents
+
+  my $parents = $job->parents;
+
+Return a L<Mojo::Collection> object containing all jobs this job depends on as L<Minion::Job> objects.
+
+  # Check parent state
+  for my $parent ($job->parents->each) {
+    my $info = $parent->info;
+    say "$info->{id}: $info->{state}";
+  }
+
 =head2 perform
 
   $job->perform;
@@ -513,6 +538,13 @@ Delay job for this many seconds (from now), defaults to C<0>.
 Job is valid for this many seconds (from now) before it expires. Note that this option is B<EXPERIMENTAL> and might
 change without warning!
 
+=item lax
+
+  lax => 1
+
+Existing jobs this job depends on may also have transitioned to the C<failed> state to allow for it to be processed,
+defaults to C<false>. Note that this option is B<EXPERIMENTAL> and might change without warning!
+
 =item parents
 
   parents => [$id1, $id2, $id3]
@@ -562,6 +594,6 @@ Stop job performed with L</"start"> immediately. Note that this method should on
 
 =head1 SEE ALSO
 
-L<Minion>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
+L<Minion>, L<https://minion.pm>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
